@@ -307,7 +307,19 @@ system of retrieved contents."
 (defun shimbun-create-header (&optional number subject from date id
 					references chars lines xref
 					extra asis)
-  "Return a new header for a shimbun article."
+  "Return a new header for a shimbun article.
+Because `shimbun-create-header' normalizes arguments with
+`shimbun-header-normalize' before creating new header object,
+following operations are unnecessary:
+
+  * MIME-encoding of subjects and from addresses.
+  * Removal of HTML tags.
+  * Decode of HTML entities.
+  * Replacement of space characteres, such as tab, newline, and
+    linefeed.
+
+If optional 11th argument ASIS is non-nil, normalization of header
+values is suppressed."
   (let ((new (luna-make-entity 'shimbun-header :number number)))
     (inline
       (shimbun-header-set-subject new subject asis)
@@ -513,7 +525,7 @@ entities."
 	      (with-temp-buffer
 		(set-buffer-multibyte nil)
 		(let ((type (shimbun-retrieve-url url nil t base-url)))
-		  (when type
+		  (when (and type (string-match "\\`image/" type))
 		    (push (setq img
 				(cons url
 				      (shimbun-make-image-entity
@@ -858,6 +870,9 @@ Return nil, unless a content is cleared successfully.")
 (luna-define-generic shimbun-index-url (shimbun)
   "Return a index URL of SHIMBUN.")
 
+(luna-define-method shimbun-index-url ((shimbun shimbun))
+  (shimbun-url-internal shimbun))
+
 (luna-define-generic shimbun-get-headers (shimbun &optional range)
   "Return a shimbun header list of SHIMBUN.
 Optional argument RANGE is one of following:
@@ -1066,6 +1081,22 @@ is enclosed by at least one regexp grouping construct."
 	  (setq start (- (length string) tail))))
       string))))
 
+(if (fboundp 'subst-char-in-string)
+    (defalias 'shimbun-subst-char-in-string 'subst-char-in-string)
+  (defun shimbun-subst-char-in-string (fromchar tochar string
+						&optional inplace)
+    "Replace characters in STRING from FROMCHAR to TOCHAR.
+Unless optional argument INPLACE is non-nil, return a new string."
+    (let ((string (if inplace string (copy-sequence string)))
+	  (len (length string))
+	  (idx 0))
+      ;; Replace all occurrences of FROMCHAR with TOCHAR.
+      (while (< idx len)
+	(when (= (aref string idx) fromchar)
+	  (aset string idx tochar))
+	(setq idx (1+ idx)))
+      string)))
+
 (defun shimbun-message (shimbun fmt &rest args)
   "Function equivalent to `message' enabling to handle special formats.
 SHIMBUN is a shimbun entity object.  FMT and ARGS are the same as the
